import 'package:email_validator/email_validator.dart';
import 'package:flutter/material.dart';

abstract class FormViewModel with ChangeNotifier {
  var remoteServerValidationErrors = Map<String, List<String>>();

  bool validateFormInputs();

  String getFirstRemoteServerValidationError(String fieldName) {
    if (this.remoteServerValidationErrors[fieldName] == null) {
      return null;
    }

    return this.remoteServerValidationErrors[fieldName].first;
  }

  String validateEmail(String email) {
    if (!EmailValidator.validate(email)) {
      return 'Please enter valid email';
    }
    return this.getFirstRemoteServerValidationError('email');
  }

  String validatePassword(String password) {
    if (password.isEmpty) {
      return 'Please enter password';
    } else if (password.length < 6) {
      return 'Password length cannot be less than 6';
    }

    return getFirstRemoteServerValidationError('password');
  }

  String validateReEnteredPassword(String password, String reEnteredPassword) {
    if (password == reEnteredPassword) {
      return null;
    }

    return 'Re-Entered password must match entered password';
  }

  String genericTextInputValidor(
      String fieldName, String text, String onError) {
    if (text == null || text.isEmpty) {
      return onError;
    }
    return getFirstRemoteServerValidationError(fieldName);
  }
}
