import 'package:easy_pass_common/model/form_view_model.dart';
import 'package:easy_pass_common/dto/user.dart';
import 'package:easy_pass_common/exceptions/unprocessable_entity_exception.dart';
import 'package:easy_pass_common/service/user_service.dart';
import 'package:flutter/material.dart';
import 'package:get_it/get_it.dart';
import 'package:intl/intl.dart';

class SignUpViewModel extends FormViewModel {
  final user = User.fromJson(null);
  final userService = GetIt.instance<UserService>();

  final signUpFormKey = GlobalKey<FormState>();

  // Exception
  final TextEditingController dateOfBirthInputController =
      new TextEditingController();

  Future createUser() async {
    this.remoteServerValidationErrors.clear();

    if (validateFormInputs()) {
      userService
          .createUser(user)
          .then((onValue) => this.remoteServerValidationErrors.clear())
          .catchError(
              (exception) =>
                  this.remoteServerValidationErrors = exception.errors,
              test: (e) => e is UnprocessableEntity)
          .whenComplete(validateFormInputs);
    }
  }

  void updateUserDateOfBirth(DateTime dateOfBirth) {
    final dateFormat = DateFormat('d MMM y');
    dateOfBirthInputController.text = dateFormat.format(dateOfBirth);
    this.user.dateOfBirth = dateOfBirth;
    notifyListeners();
  }

  bool validateFormInputs() {
    return signUpFormKey.currentState.validate();
  }
}
