import 'package:easy_pass_common/model/sign_up_view_model.dart';
import 'package:easy_pass_common/ui/widget/sign_up_date_picket.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class SignUpView extends StatelessWidget {  
  
  @override
  Widget build(BuildContext context) {
    final signUpViewModel = Provider.of<SignUpViewModel>(context);

    return Scaffold(
      body: Container(
        margin: const EdgeInsets.only(left: 28, right: 28, top: 32),
        child: Form(
          key: signUpViewModel.signUpFormKey,
          child: ListView(
            shrinkWrap: true,
            children: <Widget>[
              Padding(
                padding: const EdgeInsets.only(bottom: 36),
                child: Text('Sign up', style: TextStyle(fontSize: 60), textAlign: TextAlign.center),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(                
                  decoration: InputDecoration(
                    labelText: 'Name',
                  ),
                  onChanged: (text) => signUpViewModel.user.name = text,
                  validator: (text) => signUpViewModel.genericTextInputValidor('name', text, 'Enter name'),
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: 'Surname',
                  ),
                  onChanged: (text) => signUpViewModel.user.surname = text,
                  validator: (text) => signUpViewModel.genericTextInputValidor('surname', text, 'Enter Surname'),
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: SignUpDatePicker()
              ), 
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: 'Email',
                  ),
                  keyboardType: TextInputType.emailAddress,
                  onChanged: (value) => signUpViewModel.user.email = value,
                  validator: (email) => signUpViewModel.validateEmail(email),
                ),
              ),            
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: 'Password',
                  ),
                  onChanged: (text) => signUpViewModel.user.password = text,
                  obscureText: true,
                  validator: signUpViewModel.validatePassword,
                ),
              ),     
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: 'Re-Enter password',
                  ),
                  onChanged: (text) => signUpViewModel.user.password = text,
                  obscureText: true,
                  validator: (text) => signUpViewModel.validateReEnteredPassword(signUpViewModel.user.password, text),
                ),
              ),                
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: TextFormField(
                  decoration: InputDecoration(
                    labelText: 'Phone',
                  ),
                  onChanged: (text) => signUpViewModel.user.phone = text,
                  keyboardType: TextInputType.phone,
                  validator: (text) => signUpViewModel.genericTextInputValidor('phone', text, 'Enter cellphone number'),
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(8, 16, 8, 8),
                child: RaisedButton(
                  child: Text('Sign up'.toUpperCase(), style: Theme.of(context).textTheme.button),
                  shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(24.0)),
                  onPressed: signUpViewModel.createUser,
                ),
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Text('Already have an account? '),
                    GestureDetector(
                      child: Text('Sign in', style: TextStyle(color: Colors.blue)),
                      onTap: () => Navigator.popAndPushNamed(context, '/login'),
                    )
                  ],
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}