import 'dart:io';

import 'package:easy_pass_common/model/sing_in_view_model.dart';
import 'package:easy_pass_common/ui/widget/network_error_dialog.dart';
import 'package:easy_pass_common/ui/widget/sing_in_error_dialog.dart';
import 'package:easy_pass_common/exceptions/unauthorized_exception.dart';

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class SignInButton extends StatelessWidget {
  
  @override
  Widget build(BuildContext context) {

    final signInViewModel = Provider.of<SignInViewModel>(context);

    return Container(
      padding: const EdgeInsets.only(top: 8),
      child:  RaisedButton(
        onPressed: () => handleLogin(context, signInViewModel),
        child: Text(
                'Sign in'.toUpperCase(),
                style: Theme.of(context).textTheme.button
              ),
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(24.0)),
        color: Theme.of(context).accentColor,
      ),
    );
  }

  handleLogin(BuildContext context, SignInViewModel signInViewModel) async {
    try {
      if (await signInViewModel.singIn()) {
        Navigator.pushNamed(context, '/home');
      }
    } on SocketException catch(_) {
      showNetWorkErrorDialog(context);
    } on UnAuthorizedException catch(_) {
      showSignInErrorDialog(context);
    }
  }  
}